{
  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    nixos-unstable.url = "github:NixOS/nixpkgs/master";
    home-manager = {
      url = "github:nix-community/home-manager";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs =
    inputs@{ self, nixpkgs, nixos-unstable, home-manager }:
    let
      x64System = "x86_64-linux";
      darwinSystem = "aarch64-darwin";

      wrapPkgsSystem = { system }:
        import nixpkgs rec {
          inherit system;
          unstable = wrapUnstablePkgsSystem { inherit system; };
          config.allowUnfree = true;
          overlays = [
            (final: prev: { inherit unstable; })
          ];
        };

      wrapUnstablePkgsSystem = { system }:
        import nixos-unstable {
          inherit system;
          config.allowUnfree = true;
        };

      pkgsX64 = wrapPkgsSystem { system = x64System; };
      unstableX64 = wrapPkgsSystem { system = x64System; };
      utilsX64 = import ./lib {
        inherit nixpkgs nixos-unstable home-manager;
        pkgs = pkgsX64;
        unstable = unstableX64;
        system = x64System;
      };

      pkgsDarwin = wrapPkgsSystem { system = darwinSystem; };
      unstableDarwin = wrapPkgsSystem { system = darwinSystem; };
      utilsDarwin = import ./lib {
        inherit nixpkgs nixos-unstable home-manager;
        pkgs = pkgsDarwin;
        unstable = unstableDarwin;
        system = darwinSystem;
      };
    in {
      nixosConfigurations = {
        architect = utilsX64.host.mkHost {
          name = "architect";
          users = [{
            user = "giulio";
            roles = [ ];
          }];
        };
        gAluminum = utilsX64.host.mkHost {
          name = "gAluminum";
          users = [{
            user = "giulio";
            roles = [ "desktop" "ssh" "git" ];
          }];
          roles = [ "gnome" ];
        };
        proxy = utilsX64.host.mkHost {
          name = "proxy";
          users = [ ];
        };
      };
      homeConfigurations.giulioMac = utilsDarwin.user.mkHMUser {
        name = "giulio";
        roles = [ "ssh" ];
      };
    };
}
